@@ -62,7 +62,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK @EXPORT);
 @EXPORT_OK   = ( );
 @EXPORT      = ( );
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $PKG = __PACKAGE__;		# For interpolating into error messages
 
@@ -123,7 +123,7 @@ sub new {
 	if (my $p = delete $param{trace}) {
 	    if ($p eq '1') {
 		my @lt = localtime;
-		$p = sprintf(".trace.%04d-%02d-%02d_%02d%02d%02d",
+		$p = sprintf(".ws23xx-trace.%04d-%02d-%02d_%02d%02d%02d",
 			     $lt[5]+1900,$lt[4]+1,@lt[3,2,1,0]);
 	    }
 	    _ws_trace_path($p);
@@ -246,11 +246,14 @@ sub get {
     my $expr = $get->{expr};
 
     # Special case for datetime: return a unix time_t
-    sub _time_convert($) {
-	#             YY      MM     DD    hh    mm
-	$_[0] =~ m!^(\d{1,2})(\d\d)(\d\d)(\d\d)(\d\d)$!
-	  or die "$ME: Internal error: bad datetime '$_[0]'";
-	return timelocal( 0,$5,$4, $3, $2-1, $1+100);
+    sub _time_convert($$) {
+        #                 YY      MM     DD    hh    mm
+        if ($_[0] =~ m!^(\d{1,2})(\d\d)(\d\d)(\d\d)(\d\d)$!) {
+            return timelocal( 0,$5,$4, $3, $2-1, $1+100);
+        }
+
+        carp "$ME: ->$_[1](): WARNING: bad datetime '$_[0]'";
+        return 0;
     }
 
     # Special case for values with well-defined meanings:
@@ -275,7 +278,7 @@ sub get {
     # Interpret the equation, e.g. $BCD / 10.0
     my $val = eval($expr);
     if ($@) {
-	croak "$ME: eval( $get->{expr} ) died: $@";
+	croak "$ME: ->$field(): eval( $get->{expr} ) died: $@";
     }
 
     # Asked to convert units?
@@ -508,21 +511,21 @@ Available options are:
 
 =over 3
 
-=item B<cache_expire> =E<gt> SECONDS
+=item B<cache_expire> =E<gt> SECONDS (default: B<10>)
 
 How long to keep cached data.  If your WS-23xx uses a cabled connection,
 you probably want to set this to 8 seconds or less.  If you use a wireless
 connection, you might want to go as far as 128 seconds.  To disable
 caching entirely, set to B<0>.
 
-=item B<cache_readahead> =E<gt> NYBBLES
+=item B<cache_readahead> =E<gt> NYBBLES (default: B<30>)
 
 How much data to cache (max B<30>).
 
 =item B<trace> =E<gt> PATH
 
 Log all serial I/O to B<PATH>.  If PATH is just '1', a filename
-is autogenerated of the form F<.trace.YYYY-MM-DD_hhmmss>.
+is autogenerated of the form F<.ws23xx-trace.YYYY-MM-DD_hhmmss>.
 
 =back
 
@@ -584,7 +587,7 @@ directly mapped to the array:
 
 Note that each value is a B<nybble>: a value between 0 and 0xF.
 
-This is not really useful for actual weather station monitoring.
+The tied interface is not really useful for actual weather station monitoring.
 It is intended for hackers who want direct access to the device,
 either for learning purposes or because Device::LaCrosse::WS23xx
 is missing some important mappings.
